@@ -23,6 +23,8 @@
 #define HAVE_SYS_TIME_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_DIRECT_H 1
+#define uid_t int
+#define gid_t int
 #define HAVE_ST_RDEV 1
 #define GETGROUPS_T int
 #define RETSIGTYPE void
@@ -37,13 +39,14 @@
 #define HAVE_STRCHR 1
 #define HAVE_STRSTR 1
 #define HAVE_STRTOUL 1
+#define HAVE_VSNPRINTF 1
+#define HAVE_ISNAN 1
+#define HAVE_FINITE 1
 #define HAVE_FMOD 1
 #define HAVE_WAITPID 1
 #define HAVE_GETCWD 1
 #define HAVE_CHSIZE 1
 #define HAVE_TIMES 1
-#define HAVE_SETEUID 1
-#define HAVE_SETEGID 1
 #define HAVE__SETJMP 1
 #define HAVE_TELLDIR 1
 #define HAVE_SEEKDIR 1
@@ -53,7 +56,6 @@
 #define RSHIFT(x,y) ((x)>>(int)y)
 #define FILE_COUNT _cnt
 #define DEFAULT_KCODE KCODE_NONE
-#define USE_ELF 1
 #define DLEXT ".so"
 #define DLEXT2 ".dll"
 #define RUBY_LIB "/lib/ruby/1.6"
