@@ -1,24 +1,24 @@
 
+# This file was created by mkconfig.rb when ruby was built.  Any
+# changes made to this file will be lost the next time ruby is built.
+
 module Config
+  RUBY_VERSION == "1.6.8" or
+    raise "ruby lib version (1.6.8) doesn't match executable version (#{RUBY_VERSION})"
 
-  RUBY_VERSION == "1.6.7" or
-    raise "ruby lib version (1.6.7) doesn't match executable version (#{RUBY_VERSION})"
-
-# This file was created by configrb when ruby was built. Any changes
-# made to this file will be lost the next time ruby is built.
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-mingw32\Z', '')
-  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.7"
+  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.8/ruby16"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["CFLAGS"] = "-DNT -D__MSVCRT__ -Os"
+  CONFIG["CFLAGS"] = "-DNT -D__NO_ISOCEXT -Os"
   CONFIG["CPPFLAGS"] = ""
   CONFIG["CXXFLAGS"] = ""
   CONFIG["FFLAGS"] = ""
-  CONFIG["LDFLAGS"] = ""
+  CONFIG["LDFLAGS"] = "-Wl,--stack,0x02000000"
   CONFIG["LIBS"] = "-lwsock32 -lmsvcrt"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
@@ -35,7 +35,7 @@ module Config
   CONFIG["mandir"] = "$(prefix)/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "7"
+  CONFIG["TEENY"] = "8"
   CONFIG["host"] = "i686-pc-cygwin"
   CONFIG["host_alias"] = "i686-pc-cygwin"
   CONFIG["host_cpu"] = "i686"
@@ -53,6 +53,9 @@ module Config
   CONFIG["build_os"] = "linux-gnu"
   CONFIG["CC"] = "gcc -mno-cygwin"
   CONFIG["CPP"] = "gcc -mno-cygwin -E"
+  CONFIG["GNU_LD"] = "yes"
+  CONFIG["CPPOUTFILE"] = ""
+  CONFIG["OUTFLAG"] = "-o"
   CONFIG["YACC"] = "bison -y"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["AR"] = "ar"
@@ -64,7 +67,7 @@ module Config
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
   CONFIG["OBJEXT"] = "o"
-  CONFIG["LIBOBJS"] = "crypt.o flock.o vsnprintf.o isinf.o isnan.o finite.o strtod.o win32.o"
+  CONFIG["LIBOBJS"] = "crypt.o flock.o isinf.o win32.o"
   CONFIG["ALLOCA"] = ""
   CONFIG["XLDFLAGS"] = ""
   CONFIG["DLDFLAGS"] = ""
@@ -76,7 +79,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.7/mobj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.8/m.obj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "dllwrap --target=mingw32 --as=as --dlltool-name=dlltool --driver-name=gcc -mno-cygwin --export-all -s"
   CONFIG["LIBRUBY_DLDFLAGS"] = "--dllname=$@ --output-lib=$(LIBRUBY) --add-stdcall-alias --def=$(RUBYDEF)"
@@ -93,13 +96,13 @@ module Config
   CONFIG["MAINLIBS"] = ""
   CONFIG["arch"] = "i386-mingw32"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "--srcdir=.. --target=i386-mingw32 --host=i686-pc-cygwin --build=i586-pc-linux-gnu --includedir=/usr/local/mingw/include --enable-shared --cache=../../config.cache-mingw --enable-tcltk_stubs --with-tcllib=tclstub83 --with-tklib=tkstub83 --with-opt-dir=/usr/local/mingw"
+  CONFIG["configure_args"] = "--cache=config.cache --program-prefix= --target=i386-mingw32 --host=i686-pc-cygwin --build=i586-pc-linux-gnu --includedir=/usr/local/mingw/include --enable-shared --enable-tcltk_stubs --with-tcllib=tclstub83 --with-tklib=tkstub83 --with-dbm-type=gdbm --with-opt-dir=/usr/local/mingw"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
-  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.7/mobj"
+  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.8/m.obj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
